#!/bin/sh -efu

##
# This scrip do:
#    1) update pam_mount configuration
#    2) update pam configuration
#    3) grant anybody access to cifsmount & cifsumount
#
# Notice:
#    Network shares auto mounted only for members of `users' group.

. shell-error
. install2-init-functions

#msg() {
#    printf "$* \n"
#}

pmconf="$destdir/etc/security/pam_mount.conf.xml"
pamconf="$destdir/etc/pam.d/system-auth"

##
# Update pam_mount configuration file
#
update_pmconf() {

    local insert_at tmp_conf

    tmp_conf="${pmconf}.new"

    if ! [ -w "$pmconf" ]; then
        msg "Can't find writable $pmconf. Did you install pam_mount package?"
        return 1
    fi

    grep -qs dnssd_lookup "$pmconf" 2>/dev/null
    if [ "$?" = "0" ]; then
        msg "Suppose you already configured pam_mount. Do nothing."
        return 0
    fi

    msg "Insert settings to $pmconf to use avahi."

    insert_at="$(sed -n '/<!-- Volume definitions -->/=' "$pmconf" | head -n 1)"

    if [ -z "$insert_at" ]; then
        msg "Can't find position for injection in $pmconf"
        return 1
    fi

    # part 1 (head)
    head -n $((insert_at-1)) "$pmconf" > "$tmp_conf"

    # part 2 (inserted text)
    cat >> "$tmp_conf" <<'__EOF__'

<!-- # inserted by installer HOOK ################################# -->

<volume uid="5000-10000" noroot="1" fstype="cifs" dnssd_lookup="1" mountpoint="/home/%(USER)/share" options="sec=krb5" />
<cifsmount>/usr/bin/cifsmount //%(SERVER)/%(VOLUME) %(MNTPT) -o %(OPTIONS)</cifsmount>
<cifsumount>/usr/bin/cifsumount %(MNTPT)</cifsumount>

<!-- ############################################################## -->

__EOF__

    # part 3 (tail)
    sed -n "$insert_at,\$p" "$pmconf" >> "$tmp_conf"

    # Update config
    mv -f "$tmp_conf" "$pmconf"
    chown root.root "$pmconf"
    chmod 644 "$pmconf"

    # XXX: REMOVE FOR RELEASE
    # sed -i -e '/debug enable/ s/0/1/' "$pmconf"
}

##
# Update pam configuration
#
update_pam() {
    local append_after

    if ! [ -w "$pamconf" ]; then
        msg "Can't find writable $pamconf"
        return 1
    fi

    if [ -L "$pamconf" ]; then
        pamconf="${pamconf/$(basename $pamconf)/}$(readlink "$pamconf")"
    fi

    if grep -qs pam_mount "$pamconf"; then
        msg "Suppose you already configured pam for using pam_mount. Do nothing."
        return 0
    fi

    msg "Insert settings to $pamconf to use pam_mount."

    append_after="$(sed -n '/^auth[[:space:]]\+required/=' "$pamconf" | tail -n 1)"
    test -n "$append_after" && sed -i -e "$append_after a auth     optional       pam_mount.so"  "$pamconf"
    append_after="$(sed -n '/^session[[:space:]]\+required/=' "$pamconf" | tail -n 1)"
    test -n "$append_after" && sed -i -e "$append_after a session  optional       pam_mount.so"  "$pamconf"

    msg "Set ccache to predicadable value."
    subst 's|pam_krb5.so use_first_pass$|pam_krb5.so use_first_pass ccache=/tmp/krb5cc_%u|' "$pamconf"
}

##
# Start
#
update_pmconf &&
update_pam &&
exec_chroot /usr/sbin/control cifsmount public &&
exec_chroot /usr/sbin/control cifsumount public

